<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @package    Chikkili
 * @subpackage Chikkili/admin
 * @author     Sevengits <support@sevengits.com>
 */
class Chikkili_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	


	/**
	*  @since 1.0.0  
	* 
	*/
	 function sgpay_gateway_init()
	 {
 		/**
		 * The class responsible for google pay payment gateway.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-chikkili-payment-gateway.php';
	 
	}
	/**
	 * @since 1.0.0  
	 * Add the gateway to WC Available Gateways
	 */
		
	function sgpay_wc_add_to_gateways( $gateways ) {
			
		$gateways[] = 'Sgpay_Gateway';
		return $gateways;

	}
	/**
	 * Enable google pay if visitor is using chrome 60+ and thorugh mobile
	 *
	 * @param [array] $available_gateways
	 * @return [array]
	 * @since 1.0.0
	 */
	function conditional_payment_gateways( $available_gateways ) {
		// Not in backend (admin)
		if( is_admin() ){
			return $available_gateways;
		} 
		//return $available_gateways;
		
		$user_browser = $this->getBrowser();
		

		// check user is using chrome or not
		if($user_browser['browser']!=="Chrome" || $user_browser['version'] < 60 || !wp_is_mobile() ){
			
			unset($available_gateways['sg_gpay']); // unset google pay
			return $available_gateways;

		}else{
			return $available_gateways;
		}
		
	}
 public function getBrowser()
	{
    $u_agent = $_SERVER['HTTP_USER_AGENT'];
    $bname = 'Unknown';
    $version= '';
	$ub = 'Unknown';
    
   
    // Next get the name of the useragent yes seperately and for good reason
  if(preg_match('/Chrome/i',$u_agent))
    {
        $bname = 'Google Chrome';
        $ub = "Chrome";
    }
    
    // finally get the correct version number
    $known = array('Version', $ub, 'other');
    $pattern = '#(?<browser>' . join('|', $known) .
    ')[/ ]+(?<version>[0-9.|a-zA-Z.]*)#';
    if (!preg_match_all($pattern, $u_agent, $matches)) {
        // we have no matching number just continue
    }
   
    // see how many we have
    $i = count($matches['browser']);
    if ($i != 1) {
        //we will have two since we are not using 'other' argument yet
        //see if version is before or after the name
        if (strripos($u_agent,"Version") < strripos($u_agent,$ub)){
            $version= $matches['version'][0];
        }
        else {
            $version= $matches['version'][1];
        }
    }
    else {
        $version= $matches['version'][0];
    }
   
    $user_browser_version= explode(".",$version);

   
    $bwsr= array(
        'name'      => $bname,
        'version'   => intval($user_browser_version[0])?? 0,
		'browser'      => $ub,
        );

	return $bwsr;
}

}
?>